# Resource object code (Python 3)
# Created by: object code
# Created by: The Resource Compiler for Qt version 5.15.2
# WARNING! All changes made in this file will be lost!

from PySide2 import QtCore

qt_resource_data = b"\
\x00\x00\x09q\
<\
?xml version=\x221.\
0\x22 encoding=\x22UTF\
-8\x22 standalone=\x22\
no\x22?>\x0d\x0a<svg\x0d\x0a   \
xmlns:dc=\x22http:/\
/purl.org/dc/ele\
ments/1.1/\x22\x0d\x0a   \
xmlns:cc=\x22http:/\
/creativecommons\
.org/ns#\x22\x0d\x0a   xm\
lns:rdf=\x22http://\
www.w3.org/1999/\
02/22-rdf-syntax\
-ns#\x22\x0d\x0a   xmlns:\
svg=\x22http://www.\
w3.org/2000/svg\x22\
\x0d\x0a   xmlns=\x22http\
://www.w3.org/20\
00/svg\x22\x0d\x0a   xmln\
s:sodipodi=\x22http\
://sodipodi.sour\
ceforge.net/DTD/\
sodipodi-0.dtd\x22\x0d\
\x0a   xmlns:inksca\
pe=\x22http://www.i\
nkscape.org/name\
spaces/inkscape\x22\
\x0d\x0a   inkscape:ve\
rsion=\x221.0 (4035\
a4fb49, 2020-05-\
01)\x22\x0d\x0a   sodipod\
i:docname=\x22epoch\
-encoder-seek.sv\
g\x22\x0d\x0a   id=\x22svg6\x22\
\x0d\x0a   version=\x221.\
1\x22\x0d\x0a   viewBox=\x22\
0 0 16 16\x22>\x0d\x0a  <\
metadata\x0d\x0a     i\
d=\x22metadata10\x22>\x0d\
\x0a    <rdf:RDF>\x0d\x0a\
      <cc:Work\x0d\x0a\
         rdf:abo\
ut=\x22\x22>\x0d\x0a        \
<dc:format>image\
/svg+xml</dc:for\
mat>\x0d\x0a        <d\
c:type\x0d\x0a        \
   rdf:resource=\
\x22http://purl.org\
/dc/dcmitype/Sti\
llImage\x22 />\x0d\x0a   \
   </cc:Work>\x0d\x0a \
   </rdf:RDF>\x0d\x0a \
 </metadata>\x0d\x0a  \
<sodipodi:namedv\
iew\x0d\x0a     inksca\
pe:current-layer\
=\x22g40\x22\x0d\x0a     ink\
scape:window-max\
imized=\x221\x22\x0d\x0a    \
 inkscape:window\
-y=\x2232\x22\x0d\x0a     in\
kscape:window-x=\
\x22-8\x22\x0d\x0a     inksc\
ape:cy=\x227.146120\
2\x22\x0d\x0a     inkscap\
e:cx=\x221.3121066\x22\
\x0d\x0a     inkscape:\
zoom=\x2232\x22\x0d\x0a     \
inkscape:bbox-pa\
ths=\x22false\x22\x0d\x0a   \
  inkscape:bbox-\
nodes=\x22true\x22\x0d\x0a  \
   inkscape:snap\
-bbox-edge-midpo\
ints=\x22true\x22\x0d\x0a   \
  inkscape:snap-\
bbox-midpoints=\x22\
true\x22\x0d\x0a     inks\
cape:snap-bbox=\x22\
true\x22\x0d\x0a     show\
grid=\x22false\x22\x0d\x0a  \
   id=\x22namedview\
8\x22\x0d\x0a     inkscap\
e:window-height=\
\x221017\x22\x0d\x0a     ink\
scape:window-wid\
th=\x221920\x22\x0d\x0a     \
inkscape:pagesha\
dow=\x222\x22\x0d\x0a     in\
kscape:pageopaci\
ty=\x220\x22\x0d\x0a     gui\
detolerance=\x2210\x22\
\x0d\x0a     gridtoler\
ance=\x2210\x22\x0d\x0a     \
objecttolerance=\
\x2210\x22\x0d\x0a     borde\
ropacity=\x221\x22\x0d\x0a  \
   bordercolor=\x22\
#666666\x22\x0d\x0a     p\
agecolor=\x22#fffff\
f\x22\x0d\x0a     inkscap\
e:document-rotat\
ion=\x220\x22 />\x0d\x0a  <d\
efs\x0d\x0a     id=\x22de\
fs3051\x22>\x0d\x0a    <s\
tyle\x0d\x0a       id=\
\x22current-color-s\
cheme\x22\x0d\x0a       t\
ype=\x22text/css\x22>\x0d\
\x0a      .ColorSch\
eme-Text {\x0d\x0a    \
    color:#23262\
9;\x0d\x0a      }\x0d\x0a   \
   </style>\x0d\x0a  <\
/defs>\x0d\x0a  <g\x0d\x0a  \
   transform=\x22tr\
anslate(0.031249\
78,-0.15625)\x22\x0d\x0a \
    id=\x22g40\x22>\x0d\x0a \
   <rect\x0d\x0a      \
 style=\x22color:#0\
00000;overflow:v\
isible;fill:#232\
629;stroke-width\
:23.968;stroke-l\
inecap:round\x22\x0d\x0a \
      id=\x22rect12\
\x22\x0d\x0a       width=\
\x224.9142199\x22\x0d\x0a   \
    height=\x229.90\
02571\x22\x0d\x0a       x\
=\x225.6991401\x22\x0d\x0a  \
     y=\x22-9.91887\
86\x22\x0d\x0a       tran\
sform=\x22rotate(90\
)\x22 />\x0d\x0a    <path\
\x0d\x0a       id=\x22pat\
h4\x22\x0d\x0a       clas\
s=\x22ColorScheme-T\
ext\x22\x0d\x0a       d=\x22\
m 5.918879,0.218\
75 v 15.875 l 10\
,-7.9375 z\x22\x0d\x0a   \
    style=\x22color\
:#232629;fill:cu\
rrentColor;fill-\
opacity:1;stroke\
:none;stroke-wid\
th:1.25996\x22 />\x0d\x0a\
  </g>\x0d\x0a</svg>\x0d\x0a\
\
\x00\x00\x0d\xad\
<\
?xml version=\x221.\
0\x22 encoding=\x22UTF\
-8\x22 standalone=\x22\
no\x22?>\x0d\x0a<svg\x0d\x0a   \
xmlns:dc=\x22http:/\
/purl.org/dc/ele\
ments/1.1/\x22\x0d\x0a   \
xmlns:cc=\x22http:/\
/creativecommons\
.org/ns#\x22\x0d\x0a   xm\
lns:rdf=\x22http://\
www.w3.org/1999/\
02/22-rdf-syntax\
-ns#\x22\x0d\x0a   xmlns:\
svg=\x22http://www.\
w3.org/2000/svg\x22\
\x0d\x0a   xmlns=\x22http\
://www.w3.org/20\
00/svg\x22\x0d\x0a   xmln\
s:sodipodi=\x22http\
://sodipodi.sour\
ceforge.net/DTD/\
sodipodi-0.dtd\x22\x0d\
\x0a   xmlns:inksca\
pe=\x22http://www.i\
nkscape.org/name\
spaces/inkscape\x22\
\x0d\x0a   viewBox=\x220 \
0 16 16\x22\x0d\x0a   ver\
sion=\x221.1\x22\x0d\x0a   i\
d=\x22svg6\x22\x0d\x0a   sod\
ipodi:docname=\x22e\
poch-encoder-und\
o.svg\x22\x0d\x0a   inksc\
ape:version=\x221.0\
 (4035a4fb49, 20\
20-05-01)\x22>\x0d\x0a  <\
metadata\x0d\x0a     i\
d=\x22metadata10\x22>\x0d\
\x0a    <rdf:RDF>\x0d\x0a\
      <cc:Work\x0d\x0a\
         rdf:abo\
ut=\x22\x22>\x0d\x0a        \
<dc:format>image\
/svg+xml</dc:for\
mat>\x0d\x0a        <d\
c:type\x0d\x0a        \
   rdf:resource=\
\x22http://purl.org\
/dc/dcmitype/Sti\
llImage\x22 />\x0d\x0a   \
     <dc:title><\
/dc:title>\x0d\x0a    \
  </cc:Work>\x0d\x0a  \
  </rdf:RDF>\x0d\x0a  \
</metadata>\x0d\x0a  <\
sodipodi:namedvi\
ew\x0d\x0a     inkscap\
e:document-rotat\
ion=\x220\x22\x0d\x0a     pa\
gecolor=\x22#ffffff\
\x22\x0d\x0a     borderco\
lor=\x22#666666\x22\x0d\x0a \
    borderopacit\
y=\x221\x22\x0d\x0a     obje\
cttolerance=\x2210\x22\
\x0d\x0a     gridtoler\
ance=\x2210\x22\x0d\x0a     \
guidetolerance=\x22\
10\x22\x0d\x0a     inksca\
pe:pageopacity=\x22\
0\x22\x0d\x0a     inkscap\
e:pageshadow=\x222\x22\
\x0d\x0a     inkscape:\
window-width=\x2219\
20\x22\x0d\x0a     inksca\
pe:window-height\
=\x221001\x22\x0d\x0a     id\
=\x22namedview8\x22\x0d\x0a \
    showgrid=\x22fa\
lse\x22\x0d\x0a     inksc\
ape:snap-bbox=\x22t\
rue\x22\x0d\x0a     inksc\
ape:snap-bbox-mi\
dpoints=\x22true\x22\x0d\x0a\
     inkscape:sn\
ap-bbox-edge-mid\
points=\x22true\x22\x0d\x0a \
    inkscape:bbo\
x-nodes=\x22true\x22\x0d\x0a\
     inkscape:bb\
ox-paths=\x22false\x22\
\x0d\x0a     inkscape:\
zoom=\x2232\x22\x0d\x0a     \
inkscape:cx=\x228.2\
26097\x22\x0d\x0a     ink\
scape:cy=\x227.5297\
539\x22\x0d\x0a     inksc\
ape:window-x=\x22-9\
\x22\x0d\x0a     inkscape\
:window-y=\x2241\x22\x0d\x0a\
     inkscape:wi\
ndow-maximized=\x22\
1\x22\x0d\x0a     inkscap\
e:current-layer=\
\x22g885\x22 />\x0d\x0a  <de\
fs\x0d\x0a     id=\x22def\
s3051\x22>\x0d\x0a    <st\
yle\x0d\x0a       type\
=\x22text/css\x22\x0d\x0a   \
    id=\x22current-\
color-scheme\x22>\x0d\x0a\
      .ColorSche\
me-Text {\x0d\x0a     \
   color:#232629\
;\x0d\x0a      }\x0d\x0a    \
  </style>\x0d\x0a  </\
defs>\x0d\x0a  <g\x0d\x0a   \
  id=\x22g40\x22\x0d\x0a    \
 transform=\x22tran\
slate(0.03124978\
,-0.15625)\x22>\x0d\x0a  \
  <g\x0d\x0a       tra\
nsform=\x22matrix(-\
1.0478301,0,0,1.\
0478301,15.30897\
,-0.87676339)\x22\x0d\x0a\
       id=\x22g871\x22\
>\x0d\x0a      <g\x0d\x0a   \
      transform=\
\x22translate(-0.41\
834834,-0.121797\
88)\x22\x0d\x0a         i\
d=\x22g881\x22>\x0d\x0a     \
   <g\x0d\x0a         \
  transform=\x22mat\
rix(-1,0,0,1,14.\
891757,0.0596470\
5)\x22\x0d\x0a           \
id=\x22g885\x22>\x0d\x0a    \
      <g\x0d\x0a      \
       transform\
=\x22matrix(-1,0,0,\
1,14.93633,1.628\
9895e-4)\x22\x0d\x0a     \
        id=\x22g889\
\x22>\x0d\x0a            \
<path\x0d\x0a         \
      id=\x22path4-\
6\x22\x0d\x0a            \
   class=\x22ColorS\
cheme-Text\x22\x0d\x0a   \
            d=\x22M\
 10.056273,1.354\
6116 7.8826465,8\
.3895922 13.4009\
44,6.2413157 Z\x22\x0d\
\x0a               \
style=\x22color:#23\
2629;fill:curren\
tColor;fill-opac\
ity:1;stroke:non\
e;stroke-width:0\
.584393\x22 />\x0d\x0a   \
         <path\x0d\x0a\
               s\
tyle=\x22color:#000\
000;overflow:vis\
ible;fill:none;s\
troke:#232629;st\
roke-width:1.963\
1;stroke-linecap\
:square;stroke-m\
iterlimit:4;stro\
ke-dasharray:non\
e;stroke-opacity\
:1\x22\x0d\x0a           \
    id=\x22path837-\
5\x22\x0d\x0a            \
   transform=\x22ro\
tate(49.43912)\x22\x0d\
\x0a               \
d=\x22M 17.566429,0\
.6638031 A 5.061\
4376,5.1534634 0\
 0 1 13.194504,5\
.7692229 5.06143\
76,5.1534634 0 0\
 1 7.6314166,2.0\
548116 5.0614376\
,5.1534634 0 0 1\
 10.487638,-4.06\
26264\x22\x0d\x0a        \
       sodipodi:\
type=\x22arc\x22\x0d\x0a    \
           sodip\
odi:arc-type=\x22ar\
c\x22\x0d\x0a            \
   sodipodi:star\
t=\x220\x22\x0d\x0a         \
      sodipodi:e\
nd=\x224.3024284\x22\x0d\x0a\
               s\
odipodi:ry=\x225.15\
34634\x22\x0d\x0a        \
       sodipodi:\
rx=\x225.0614376\x22\x0d\x0a\
               s\
odipodi:cy=\x220.66\
38031\x22\x0d\x0a        \
       sodipodi:\
cx=\x2212.504992\x22\x0d\x0a\
               s\
odipodi:open=\x22tr\
ue\x22 />\x0d\x0a        \
  </g>\x0d\x0a        \
</g>\x0d\x0a      </g>\
\x0d\x0a    </g>\x0d\x0a  </\
g>\x0d\x0a</svg>\x0d\x0a\
\x00\x00\x01p\
<\
svg xmlns=\x22http:\
//www.w3.org/200\
0/svg\x22 viewBox=\x22\
0 0 16 16\x22>\x0d\x0a  <\
defs id=\x22defs305\
1\x22>\x0d\x0a    <style \
type=\x22text/css\x22 \
id=\x22current-colo\
r-scheme\x22>\x0d\x0a    \
  .ColorScheme-T\
ext {\x0d\x0a        c\
olor:#232629;\x0d\x0a \
     }\x0d\x0a      </\
style>\x0d\x0a  </defs\
>\x0d\x0a <path style=\
\x22fill:currentCol\
or;fill-opacity:\
1;stroke:none\x22\x0d\x0a\
       d=\x22m 3 3 \
0 10 10 -5 z\x22\x0d\x0a \
    class=\x22Color\
Scheme-Text\x22\x0d\x0a  \
   />\x0d\x0a</svg>\x0d\x0a\
\x00\x00\x01u\
<\
svg xmlns=\x22http:\
//www.w3.org/200\
0/svg\x22 viewBox=\x22\
0 0 16 16\x22>\x0d\x0a  <\
defs id=\x22defs305\
1\x22>\x0d\x0a    <style \
type=\x22text/css\x22 \
id=\x22current-colo\
r-scheme\x22>\x0d\x0a    \
  .ColorScheme-T\
ext {\x0d\x0a        c\
olor:#232629;\x0d\x0a \
     }\x0d\x0a      </\
style>\x0d\x0a  </defs\
>\x0d\x0a <path style=\
\x22fill:currentCol\
or;fill-opacity:\
1;stroke:none\x22\x0d\x0a\
       d=\x22m 3 3 \
0 10 10 0 0 -10 \
z\x22\x0d\x0a     class=\x22\
ColorScheme-Text\
\x22\x0d\x0a     />\x0d\x0a</sv\
g>\x0d\x0a\
\x00\x00\x0d\xab\
<\
?xml version=\x221.\
0\x22 encoding=\x22UTF\
-8\x22 standalone=\x22\
no\x22?>\x0d\x0a<svg\x0d\x0a   \
xmlns:dc=\x22http:/\
/purl.org/dc/ele\
ments/1.1/\x22\x0d\x0a   \
xmlns:cc=\x22http:/\
/creativecommons\
.org/ns#\x22\x0d\x0a   xm\
lns:rdf=\x22http://\
www.w3.org/1999/\
02/22-rdf-syntax\
-ns#\x22\x0d\x0a   xmlns:\
svg=\x22http://www.\
w3.org/2000/svg\x22\
\x0d\x0a   xmlns=\x22http\
://www.w3.org/20\
00/svg\x22\x0d\x0a   xmln\
s:sodipodi=\x22http\
://sodipodi.sour\
ceforge.net/DTD/\
sodipodi-0.dtd\x22\x0d\
\x0a   xmlns:inksca\
pe=\x22http://www.i\
nkscape.org/name\
spaces/inkscape\x22\
\x0d\x0a   viewBox=\x220 \
0 16 16\x22\x0d\x0a   ver\
sion=\x221.1\x22\x0d\x0a   i\
d=\x22svg6\x22\x0d\x0a   sod\
ipodi:docname=\x22e\
poch-encoder-red\
o.svg\x22\x0d\x0a   inksc\
ape:version=\x221.0\
 (4035a4fb49, 20\
20-05-01)\x22>\x0d\x0a  <\
metadata\x0d\x0a     i\
d=\x22metadata10\x22>\x0d\
\x0a    <rdf:RDF>\x0d\x0a\
      <cc:Work\x0d\x0a\
         rdf:abo\
ut=\x22\x22>\x0d\x0a        \
<dc:format>image\
/svg+xml</dc:for\
mat>\x0d\x0a        <d\
c:type\x0d\x0a        \
   rdf:resource=\
\x22http://purl.org\
/dc/dcmitype/Sti\
llImage\x22 />\x0d\x0a   \
     <dc:title><\
/dc:title>\x0d\x0a    \
  </cc:Work>\x0d\x0a  \
  </rdf:RDF>\x0d\x0a  \
</metadata>\x0d\x0a  <\
sodipodi:namedvi\
ew\x0d\x0a     inkscap\
e:document-rotat\
ion=\x220\x22\x0d\x0a     pa\
gecolor=\x22#ffffff\
\x22\x0d\x0a     borderco\
lor=\x22#666666\x22\x0d\x0a \
    borderopacit\
y=\x221\x22\x0d\x0a     obje\
cttolerance=\x2210\x22\
\x0d\x0a     gridtoler\
ance=\x2210\x22\x0d\x0a     \
guidetolerance=\x22\
10\x22\x0d\x0a     inksca\
pe:pageopacity=\x22\
0\x22\x0d\x0a     inkscap\
e:pageshadow=\x222\x22\
\x0d\x0a     inkscape:\
window-width=\x2219\
20\x22\x0d\x0a     inksca\
pe:window-height\
=\x221001\x22\x0d\x0a     id\
=\x22namedview8\x22\x0d\x0a \
    showgrid=\x22fa\
lse\x22\x0d\x0a     inksc\
ape:snap-bbox=\x22t\
rue\x22\x0d\x0a     inksc\
ape:snap-bbox-mi\
dpoints=\x22true\x22\x0d\x0a\
     inkscape:sn\
ap-bbox-edge-mid\
points=\x22true\x22\x0d\x0a \
    inkscape:bbo\
x-nodes=\x22true\x22\x0d\x0a\
     inkscape:bb\
ox-paths=\x22false\x22\
\x0d\x0a     inkscape:\
zoom=\x2232\x22\x0d\x0a     \
inkscape:cx=\x228.2\
26097\x22\x0d\x0a     ink\
scape:cy=\x227.5297\
539\x22\x0d\x0a     inksc\
ape:window-x=\x22-9\
\x22\x0d\x0a     inkscape\
:window-y=\x2241\x22\x0d\x0a\
     inkscape:wi\
ndow-maximized=\x22\
1\x22\x0d\x0a     inkscap\
e:current-layer=\
\x22g885\x22 />\x0d\x0a  <de\
fs\x0d\x0a     id=\x22def\
s3051\x22>\x0d\x0a    <st\
yle\x0d\x0a       type\
=\x22text/css\x22\x0d\x0a   \
    id=\x22current-\
color-scheme\x22>\x0d\x0a\
      .ColorSche\
me-Text {\x0d\x0a     \
   color:#232629\
;\x0d\x0a      }\x0d\x0a    \
  </style>\x0d\x0a  </\
defs>\x0d\x0a  <g\x0d\x0a   \
  id=\x22g40\x22\x0d\x0a    \
 transform=\x22tran\
slate(0.03124978\
,-0.15625)\x22>\x0d\x0a  \
  <g\x0d\x0a       tra\
nsform=\x22matrix(-\
1.0478301,0,0,1.\
0478301,15.30897\
,-0.87676339)\x22\x0d\x0a\
       id=\x22g871\x22\
>\x0d\x0a      <g\x0d\x0a   \
      transform=\
\x22translate(-0.41\
834834,-0.121797\
88)\x22\x0d\x0a         i\
d=\x22g881\x22>\x0d\x0a     \
   <g\x0d\x0a         \
  transform=\x22mat\
rix(-1,0,0,1,14.\
891757,0.0596470\
5)\x22\x0d\x0a           \
id=\x22g885\x22>\x0d\x0a    \
      <g\x0d\x0a      \
       transform\
=\x22translate(1.62\
53609e-4,1.62898\
95e-4)\x22\x0d\x0a       \
      id=\x22g889\x22>\
\x0d\x0a            <p\
ath\x0d\x0a           \
    id=\x22path4-6\x22\
\x0d\x0a              \
 class=\x22ColorSch\
eme-Text\x22\x0d\x0a     \
          d=\x22M 1\
0.056273,1.35461\
16 7.8826465,8.3\
895922 13.400944\
,6.2413157 Z\x22\x0d\x0a \
              st\
yle=\x22color:#2326\
29;fill:currentC\
olor;fill-opacit\
y:1;stroke:none;\
stroke-width:0.5\
84393\x22 />\x0d\x0a     \
       <path\x0d\x0a  \
             sty\
le=\x22color:#00000\
0;overflow:visib\
le;fill:none;str\
oke:#232629;stro\
ke-width:1.9631;\
stroke-linecap:s\
quare;stroke-mit\
erlimit:4;stroke\
-dasharray:none;\
stroke-opacity:1\
\x22\x0d\x0a             \
  id=\x22path837-5\x22\
\x0d\x0a              \
 transform=\x22rota\
te(49.43912)\x22\x0d\x0a \
              d=\
\x22M 17.566429,0.6\
638031 A 5.06143\
76,5.1534634 0 0\
 1 13.194504,5.7\
692229 5.0614376\
,5.1534634 0 0 1\
 7.6314166,2.054\
8116 5.0614376,5\
.1534634 0 0 1 1\
0.487638,-4.0626\
264\x22\x0d\x0a          \
     sodipodi:ty\
pe=\x22arc\x22\x0d\x0a      \
         sodipod\
i:arc-type=\x22arc\x22\
\x0d\x0a              \
 sodipodi:start=\
\x220\x22\x0d\x0a           \
    sodipodi:end\
=\x224.3024284\x22\x0d\x0a  \
             sod\
ipodi:ry=\x225.1534\
634\x22\x0d\x0a          \
     sodipodi:rx\
=\x225.0614376\x22\x0d\x0a  \
             sod\
ipodi:cy=\x220.6638\
031\x22\x0d\x0a          \
     sodipodi:cx\
=\x2212.504992\x22\x0d\x0a  \
             sod\
ipodi:open=\x22true\
\x22 />\x0d\x0a          \
</g>\x0d\x0a        </\
g>\x0d\x0a      </g>\x0d\x0a\
    </g>\x0d\x0a  </g>\
\x0d\x0a</svg>\x0d\x0a\
\x00\x00\x09\xb5\
<\
?xml version=\x221.\
0\x22 encoding=\x22UTF\
-8\x22 standalone=\x22\
no\x22?>\x0d\x0a<svg\x0d\x0a   \
xmlns:dc=\x22http:/\
/purl.org/dc/ele\
ments/1.1/\x22\x0d\x0a   \
xmlns:cc=\x22http:/\
/creativecommons\
.org/ns#\x22\x0d\x0a   xm\
lns:rdf=\x22http://\
www.w3.org/1999/\
02/22-rdf-syntax\
-ns#\x22\x0d\x0a   xmlns:\
svg=\x22http://www.\
w3.org/2000/svg\x22\
\x0d\x0a   xmlns=\x22http\
://www.w3.org/20\
00/svg\x22\x0d\x0a   xmln\
s:sodipodi=\x22http\
://sodipodi.sour\
ceforge.net/DTD/\
sodipodi-0.dtd\x22\x0d\
\x0a   xmlns:inksca\
pe=\x22http://www.i\
nkscape.org/name\
spaces/inkscape\x22\
\x0d\x0a   viewBox=\x220 \
0 16 16\x22\x0d\x0a   ver\
sion=\x221.1\x22\x0d\x0a   i\
d=\x22svg6\x22\x0d\x0a   sod\
ipodi:docname=\x22e\
poch-encoder-del\
ete.svg\x22\x0d\x0a   ink\
scape:version=\x221\
.0 (4035a4fb49, \
2020-05-01)\x22>\x0d\x0a \
 <metadata\x0d\x0a    \
 id=\x22metadata10\x22\
>\x0d\x0a    <rdf:RDF>\
\x0d\x0a      <cc:Work\
\x0d\x0a         rdf:a\
bout=\x22\x22>\x0d\x0a      \
  <dc:format>ima\
ge/svg+xml</dc:f\
ormat>\x0d\x0a        \
<dc:type\x0d\x0a      \
     rdf:resourc\
e=\x22http://purl.o\
rg/dc/dcmitype/S\
tillImage\x22 />\x0d\x0a \
       <dc:title\
 />\x0d\x0a      </cc:\
Work>\x0d\x0a    </rdf\
:RDF>\x0d\x0a  </metad\
ata>\x0d\x0a  <sodipod\
i:namedview\x0d\x0a   \
  inkscape:docum\
ent-rotation=\x220\x22\
\x0d\x0a     pagecolor\
=\x22#ffffff\x22\x0d\x0a    \
 bordercolor=\x22#6\
66666\x22\x0d\x0a     bor\
deropacity=\x221\x22\x0d\x0a\
     objecttoler\
ance=\x2210\x22\x0d\x0a     \
gridtolerance=\x221\
0\x22\x0d\x0a     guideto\
lerance=\x2210\x22\x0d\x0a  \
   inkscape:page\
opacity=\x220\x22\x0d\x0a   \
  inkscape:pages\
hadow=\x222\x22\x0d\x0a     \
inkscape:window-\
width=\x221920\x22\x0d\x0a  \
   inkscape:wind\
ow-height=\x221017\x22\
\x0d\x0a     id=\x22named\
view8\x22\x0d\x0a     sho\
wgrid=\x22false\x22\x0d\x0a \
    inkscape:sna\
p-bbox=\x22true\x22\x0d\x0a \
    inkscape:sna\
p-bbox-midpoints\
=\x22true\x22\x0d\x0a     in\
kscape:snap-bbox\
-edge-midpoints=\
\x22true\x22\x0d\x0a     ink\
scape:bbox-nodes\
=\x22true\x22\x0d\x0a     in\
kscape:zoom=\x2232.\
482718\x22\x0d\x0a     in\
kscape:cx=\x228.707\
8372\x22\x0d\x0a     inks\
cape:cy=\x228.35135\
5\x22\x0d\x0a     inkscap\
e:window-x=\x22-8\x22\x0d\
\x0a     inkscape:w\
indow-y=\x2232\x22\x0d\x0a  \
   inkscape:wind\
ow-maximized=\x221\x22\
\x0d\x0a     inkscape:\
current-layer=\x22s\
vg6\x22 />\x0d\x0a  <defs\
\x0d\x0a     id=\x22defs3\
051\x22>\x0d\x0a    <styl\
e\x0d\x0a       type=\x22\
text/css\x22\x0d\x0a     \
  id=\x22current-co\
lor-scheme\x22>\x0d\x0a  \
    .ColorScheme\
-Text {\x0d\x0a       \
 color:#232629;\x0d\
\x0a      }\x0d\x0a      \
</style>\x0d\x0a  </de\
fs>\x0d\x0a  <g\x0d\x0a     \
id=\x22g33\x22\x0d\x0a     t\
ransform=\x22matrix\
(1.7776366,0,0,1\
.7776366,14.1839\
94,-7.7883383)\x22>\
\x0d\x0a    <rect\x0d\x0a   \
    transform=\x22r\
otate(45)\x22\x0d\x0a    \
   y=\x223.5835483\x22\
\x0d\x0a       x=\x222.95\
8411\x22\x0d\x0a       he\
ight=\x2210.313176\x22\
\x0d\x0a       width=\x22\
1.7239937\x22\x0d\x0a    \
   id=\x22rect12\x22\x0d\x0a\
       style=\x22co\
lor:#000000;over\
flow:visible;fil\
l:#232629;stroke\
-width:12.3402;s\
troke-linecap:ro\
und\x22 />\x0d\x0a    <re\
ct\x0d\x0a       trans\
form=\x22rotate(135\
)\x22\x0d\x0a       style\
=\x22color:#000000;\
overflow:visible\
;fill:#232629;st\
roke-width:12.34\
02;stroke-lineca\
p:round\x22\x0d\x0a      \
 id=\x22rect12-7\x22\x0d\x0a\
       width=\x221.\
7239937\x22\x0d\x0a      \
 height=\x2210.3131\
76\x22\x0d\x0a       x=\x227\
.878139\x22\x0d\x0a      \
 y=\x22-8.9769955\x22 \
/>\x0d\x0a  </g>\x0d\x0a</sv\
g>\x0d\x0a\
\x00\x00\x05\x13\
\x00\
\x00\x13Tx\x9c\xd5X\xdbn\xe36\x10}_`\xff\
\xc1P^\x124\xa4H\x8a\xba9v\x16h\x17\x0b\xf4\
\xb5\x9b\xa2\xcf\xb2D\xcbj$\xd1\x10\xe9\xd8\xd9E\xff\
\xbdC\xc9\x92eKN\x9c\xa6\x17T\x89\x11\x91sf\
H\xce\x1c\x9e12\xfb\xb4+\xf2\xc9\x93\xa8T&\xcb\
\xb9E1\xb1&\xa2\x8ce\x92\x95\xe9\xdc\xfa\xf5\xe1\x0b\
\x0a\xac\x89\xd2Q\x99D\xb9,\xc5\xdc*\xa5\xf5\xe9\xfe\
\xe3\x87\x99zJ?~\x98L&\xe0^\xaai\x12\xcf\
\xad\x95\xd6\xeb\xa9m\xaf7U\x8ee\x95\xdaIl\x8b\
\x5c\x14\xa2\xd4\xca\xa6\x98\xdaV\x0f\x1f\x1f\xf0q%\x22\
\x9d=\x89X\x16\x85,U\xedZ\xaa\xab>\xbaJ\x96\
\x1d|\xbb\xdd\xe2\xadS\xa3h\x18\x866a6c\x08\
\x10H=\x97:\xda\xa1\x13_\xd8\xe7\x98/#\x84\xd8\
`\xebA/\x84M\x15$g\x0d\x9f\x0e\xdfN`%\
7U,\x96\xe0(p)\xb4\xfd\xf9\xe1sgD\x04\
':\xe9\xc7\xc9\xcaG\x15Gkq\xb4n;\xd9\xa4\
!*\x84ZG\xb1Pv;\xdf\x04hG\xd3~\xe1\
&\xd7\x9c8n\xc4\x97\x0b\x1e\xdeN\x18a\x04\x11\x17\
\x11z\xd3\xf8\xb4\x1b\x99&26\x81\xe7\x96X\xcbx\
\x85\xeaj\x8b\x0a%\x9bu\x9e\xc5\x91\x16\xb8;o\x96\
\xcc-\x18x\xcd\xa8\xb7\x16\xdd\xcfdb\xfb\xa3\xdc\xcd\
-2!\x13\xea\xc1\xafuo\x0c\xb3B\xe8(\x89t\
T\xa3\x9a8\xed\x14%\x0d\x06PP\xb4\xe9/\x9f\xbf\
\xec\x870\x11\xc7\xd3\xdfd\xf5\xd8\x8e\xe11\x90h!\
7znY\xf7\x87\xf9Y\x12O!\xcdE\xa4\xef\xb3\
\x22J\x85)\xd1\x0f\x90\xd5\x99}0\x1c\xa3\xf5\xf3Z\
\xf4\xe26\x91+\xd1Tl\x94\xbbI\x5cd\xc6\xcb\xfe\
\xaa\xb3<\xff\xd9,cM\xec\xd3\xb0\x99\xce\xc5}\xbd\
l\xf3\xda\x9d\xc5\xde\x1f\xa6=\xac\xdd?\xed\xccn\xd3\
\xd1\x0c\xbb\xda\x98\xc2$&\xadm\xe6\xdaB\xc7\x9b\xaa\
\x82\x9b\x84\xf2\xe8YTs+\xa5\xe1\xbe*=\xcc6\
+\x13\xb9EE\xb4\xcb\x8a\xec\x9b\x80\xa4\xd3s\x98\xe7\
\xb9\xc5\xcf\x1a\xa1\xa0(\x1c\x18c\xf0A\x0c\x13\xcf\xf3\
\x02\x87\x0f\xcd\xe0E\x03\xec\xf8!\xf7\xd9\xc0\xfaM\xca\
\x02\xec\x1ef\x9c:\xee0\xf8b!wh\x1d\xe9\x15\
\xdcB]m\xc48\xa0\x04\xa2\x9e\x03\xa82Z\xa3\x1a\
%\x92T\xa0\x22K\xd62\x03\xe9y\x15~1\xf2\xd8\
\xaeVr\x9bV\x86\xd9\xcb(W\x077\x98\xe8\x8a\x18\
\x9c\xcb\xf0Jd\xe9\x0a8M\x099[\x85m\x96\xe8\
\x15@BF\x06\x905\x90Q\xad\x22\x80\xcd\xada\xb2\
\x8dU\x82l\x00}\xe1j\xb6\xe6t\x93%B\xcb\x5c\
TQi(O\x0f\x168\xc6\xa8A.~\x17\xb1\x1e\
5-d\x05\xa2\xd1\xadB\x8f\xe7c\x99K`\xe9\x95\
W?\xad\xcd\xec\xab\xb5,\xebg\xb0u\xd0\xa6\x8d\xe9\
\x18\xa8\x92\x1a\xba\x82Q\x9b\xe1\xe9\xeb\x8a\xa4\xb9\x5cD\
y\x9b\xfd\xfd\xc5\x9c%b\xa9z\x950C\x87\xb8\xb4\
\x93\x1c\xa5\x9f\xf3\x83\x0e\x18H{\xb1\xea\x8d!\x15\xaf\
\xa0cY\x1d\xc2\x08\x00\xd4]\xec\xb4\x1d+u\x90 \
\xfc\x93\x81\x7f\xad\xd1\xe8\x01\xcc\x93\xef\x07a\xa8CM\
\xaf\x98\xc3<\x16\xde\xb5\xf3\x7f\x1c\xa4\xa1\xde\xc5^\x08\
\xcc\x16\x9b\xd7\xb4\xb7\xf1\xd4\xed\xb8\xa3!\xf7\xcah\x9a\
\xe1\x1f\xbc\xe6 \xd1\xd7\x04\x13\x97sF=~\x0b\x8d\
\xc5\xa1\x0eg\xc4g7\xdd9\xd3\xa33\xf6\xd5\xe2l\
@h\x18\x9e\x7fK\xb0\xe7\x90\xd0\xf5\xc2C\xb0\xa3p\
m@\x16\x1e\xe9q\x1f\xd0B\x5c\xdf:\x9a\xed\xad\x0b\
\xfa\x5ce\xbbkDo\x09\xfc\xd0[\xeab\x9f\xfb\x84\
Ss\x1a\x971\xce\x83\xd0\xbd\xe9\xaf`\xda\x05p\xf1\
(\xe0Q\xc8\x9a0\xe2:$7\xd6\x09\xc8\xe8\x16\xc5\
!a\x94;\xec\xd4hT\x0b{A\xe8\x05\x94\x9e\xda\
\xba[\x8a\xdd\xc0\x09\xc9\xd0y\x7fEA\xf5\x5c\x12x\
\xcc=\xb5\x9b<\x98]S\x8e|4\xb0\xd6,\x00\x02\
6l!\xf5s'\xa1\xcb.s\xb9\x9d>e*[\
\xe4\xe2n\x09\xcd\xa7\xe3\x92\xd2\x95|\x14\x8d4L\x19\
\xc5\xcc!^;\x99g\xa5\x80\xeb1\xad\xe4\xa6L\x8e\
;\xd5x\xf2\xfe\xd1\xf5_\xcc\x04\xf2\xdf\x9a\xc9WK\
\xf1R\x1dk\x020\xecp7\x1c\xd8\xc6\x19tA\xf6\
z\x8e\xa0J\xb9\x002\x8f3\x0f\xae*7\x97ud\
\xc7gwu)\xf3\xc0\x9f0\xdf\x1b\xa4\xf34\xddh\
\xb0\xc2\xbb\x8b\xefb\xee\x87\xce\x7fG\xbe\x97\xd6\x7f5\
\x1b\xc8{cB/\xe1\xdf\xd9j\x1a\x1a8\x98\xf9\x8e\
\x1b\xf0\x97\x08x\xe0\xd1\xf1\xf7L;}]jO+\
<*\xf2\x0e&\x01\x0bBJo9\x06\x1f\xea\xb2\x0b\
4\xf6\xbd\x95\xa2>\xa6!\xffK\x95\x0a\xcfT\xc9\xd4\
\xdew\xc2a\x15.)\x13\xc7\xae\xe7P\x97\x0c.$\
\x94\xc9\xc7\x9c\xfa\x90\xa0\x81\xfe\x0c{W\xdd\xb6\xea\xf6\
\xf5f\xbd\x18\x8b0J\x19\xc2\xdc\xc0w\x07\x5c\xfd\x17\
{\x16|\x06w\xe1\x7f\xdf\xb7\xde'\x1d\x03\xde\xfc\x1d\
\xd2q\xb6\xd6/\xb6\x90\x81v\xc0\xf7\xa7S\xf5\xb8\xb0\
{5\x9eo\x11\xae\x17\xb7})\x0d9&\xd4\xf3\x83\
a\x801\xcd\x1e\xea\xc1\xbb\xb5\x89c\x9f\x9d\xd3\xa6\xb3\
\x22|xo\xdf\x9a\xbf3\xf3o\x08\xf8\xfb'\xc4*\
\xeb|\
\x00\x00\x04\x95\
\x00\
\x00\x10Qx\x9c\xd5W\xdbn\xe36\x10}_`\xff\
AP^\x124\xa4H\xeabK\xb1\xb3@\x1b,\xd0\
\xd7n\x8a>\xcb\x12-\xab\x91DA\xa4c{\x17\xfd\
\xf7\x0e\xa5P\x17_\x9a\x04\x08\xd0V\x8eaq\xe6\x90\
\x1c\x9e93R\x16_\xf6ea=\xf3F\xe6\xa2Z\
\xda\x14\x13\xdb\xe2U\x22\xd2\xbc\xca\x96\xf6\xef\x8f_\xd1\
\xdc\xb6\xa4\x8a\xab4.D\xc5\x97v%\xec/\xf7\x9f\
?-\xe4s\xf6\xf9\x93eY0\xbd\x92Q\x9a,\xed\
\x8dRu\xe48\xf5\xb6)\xb0h2'M\x1c^\xf0\
\x92WJ:\x14S\xc7\x1e\xe1\x93\x01\x9f4<V\xf9\
3ODY\x8aJ\xb6S+y5F7\xe9\xba\x87\
\xefv;\xbcs[\x14\x0d\xc3\xd0!\xcca\x0c\x01\x02\
\xc9C\xa5\xe2=:\x9a\x0bq\x9e\x9b\xcb\x08!\x0e\xf8\
F\xd07\xc2\x22\x09\xe4\xd4\xf0\xed\xf1\xc6\x80\xa5\xd86\
\x09_\xc3D\x8e+\xae\x9c\x87\xc7\x87\xde\x89\x08NU\
:^'\xaf\x9ed\x12\xd7|\xb2\xaf1v4\xc4%\
\x97u\x9cp\xe9\x18{\xb7\x80\x19E\xe3\xc4Y\xd7\x1e\
q\xfd\xd8[\xaf\xbc\xf0\xd6b\x84\x11D|D\xe8M\
7\xc7\x04\x12\xa5\x22\xd1\x0b/m^\x8bd\x83\xdal\
\xf3\x06\xc9\xba\xc8\x15\xee\xcf\x9a\xa7K\x1b\x06A7\x1a\
\xedC_,9\xdf\xfd,\xf6K\x9bX\xc4\xa2\x01\xfc\
\xd9\xf7\xda\xb1(\xb9\x8a\xd3X\xc5-\xaa[\xc7\x98(\
\xe90\x80\x82\x84E\xbf=|}\x19\x82!I\xa2?\
D\xf3d\xc6piH\xbc\x12[\xb5\xb4\xed\xfb\xc1\xbe\
H\x93\x08(.cu\x9f\x97q\xc6uz~\x02F\
\x17\xce\xe0\x98\xa2\xd5\xa1\xe6\xa3u\xbb\x95\x1b\xdee\xeb\
\xacn\xd3\xa4\xcc\xf5,\xe7\x9b\xca\x8b\xe2W\xbd\x8dm\
9C\xb0\xceK\xb4\xe64\xce\xf88\x0b\xc7\x9c\xb7\x1b\
\xf6\xc4k\xd6S\xcd\x9b\xa1\xc6d1\xd96\x0d\x94\x09\
*\xe2\x03o\x96vF]\xcf>\xc6\xec\xf2*\x15;\
T\xc6\xfb\xbc\xcc\xbfs`\x95^\xc2\x1c\x96\xb6\xcb.\
9!cP\xd2'\x11\xc0\x9c\x19\xa6^@A7\xa7\
\xde\xbdN\xbcK\x19%Ap\xe2\xfd.Dyv\xc7\
\xd5J\xecQ\x1d\xab\x0d\x94\xd6:.$?\x8f\xa8@\
~\x80P\xcd\xf6\x14 \xab\xb8F-\x8a\xa7\x19Ge\
\x9e\xd6\x22\x87\x86\xf2*\xfc\xcd\xc8\xa9_n\xc4.k\
\xb4f\xa7\x01\x83\xa1\xcf\xde){/\xd4nx\x9em\
@\xad\x94\xd0\xd9%\xcc.O\xd5\x06 !#'\x90\
\x1ad&71\xc0\x96\xf6)\x9b\xda+\xa0\x19\x800\
\xa1\xe8\x8c;\xdb\xe6)W\xa2\xe0M\x5ci1\xd3\xc1\
\x03\xc78\xeb\x10\xab?y\xa2\xce\xbaV\xa2\x81V\xd0\
\xefB\xa7\xf6D\x14\x02\xe4y\x15\xb4\x97\xf1\xe9\xb8\x8c\
g\xdd^'\xa1C\xc7\xd9\xea\xe7\x00j\x84\x82^\xaf\
\xfb\x081\xf5\xb4H\xf9Z\x8eh\xd6C\x97\xf8\xb4\xef\
\x14R\x1d\x8a\xa1|5\xc4\x94K\xbb+\x92\xc9\x06\x1e\
2v\x8f\xd0u\x0bI\xe5{\xe5$R\x0e\x9d\x03\xff\
\xa2\xe1\xdfZ4z\x04\xb7\xf5ch\x0a\xedR\xd1\x15\
sY\xc0\xc2;c\xffk(\xf86\x8a\x97\xf2\xd6!\
v\xb7\xd9(\xf0\xb6jM\xd0\xd9\x10\x0e\x90,u[\
\xd2B\x83\xdb\x22V\xfc\x1a\x1e\x06\x04\xca\xc9'\xfe-\
\xdc\x05\xcc\xbf\xb1''\xcc(!C\xe4\x8b\x06\xf25\
j`m,@C\x173i\xaf;\x01-z]\x88\
]\xf4\x9c\xcb|U\xf0\xbb5t\xae\xfeDR5\xe2\
\x89w\xea\x8bh\x80\x03\xea\x19[\x91W\x1c\xb2\x145\
b[\xa5\xf6h\x1b\x1d\x88\xde\x992\x14\x8c\xedF\xc2\
\xd8\xa7t\xcef\xb3\xb1\xaf/\x01\x1f{\x01\x9b\xf9\x13\
\xe7^\xf7\x180\xban\xe0\x8e\xedZ\xcf\x98\x11\xe8=\
\xd4\xf3&}6;\x0a'\xa3\x01C\x93\xb9g\xe9\xa5\
\x04\xcf]w\x0e\xec\x22C\xef\xf8\x91pD\xe7\x07\x10\
\xeab\x88\xdd}\x95\xd1\x09\xa7\x04\x85\xc1\xd4yD\xec\
|\xea5\xd4\x868\xf0\xbc\x99\xcf\xfc\xa9\x1b\xc8u\xb1\
O\xa8\xcb\xfc\xa3e\xf5\xe3\x00\xd3\xd9,`\xeel\xcc\
\xee9&\x00\x8b|\x0c\xabP\xdf\x0d\xcel`\x969\
\x1b\x99\x8f\xfd`\x1eR\x7f\xfe\x9ecM\x18\x81\x8f\xfd\
\xa1\x99\x09q8#^\xf0\x86\xcc\x8c\x84\xd4v)~\
\x1d\x92\x9b\xd7\xe8:?\xe9_:\xc1\x11\x93\xf3c.\
\xdf&\xaf\x0bI\xd4o\x00\xfa\x15\x80\xf8\xde\xfcD^\
#\xc9L\xde\x92\xb2W*\xd9\x9b6\x96\x11\x9b\xf0\x12\
\xd7\xe4\xfbkDo\x09|\xe8\xad\x8f\x19\x9b\x07a\xf0\
\xc6\x82>\x5c\xd4\xea\xe52y\xa5\xbe\xde\xa1\xe2\x10\xd1\
\x8f\xd5\xc0?\xf6\x97\xff\xb1D\xdd\x8f\x96\xe8\x85\xa4_\
\x94\xe8\xfb[\xe0\x85\x22\xf8\xc8\x168G\xfe\xf4\x19\xf7\
\x9fj\x83CU\x9b\xbb\xeew\xa1\xff\x0f\x83\xdf\xbf\x01\
\xa1\x0cC\xcd\
\x00\x00\x0d\xa5\
<\
?xml version=\x221.\
0\x22 encoding=\x22UTF\
-8\x22 standalone=\x22\
no\x22?>\x0d\x0a<svg\x0d\x0a   \
xmlns:dc=\x22http:/\
/purl.org/dc/ele\
ments/1.1/\x22\x0d\x0a   \
xmlns:cc=\x22http:/\
/creativecommons\
.org/ns#\x22\x0d\x0a   xm\
lns:rdf=\x22http://\
www.w3.org/1999/\
02/22-rdf-syntax\
-ns#\x22\x0d\x0a   xmlns:\
svg=\x22http://www.\
w3.org/2000/svg\x22\
\x0d\x0a   xmlns=\x22http\
://www.w3.org/20\
00/svg\x22\x0d\x0a   xmln\
s:sodipodi=\x22http\
://sodipodi.sour\
ceforge.net/DTD/\
sodipodi-0.dtd\x22\x0d\
\x0a   xmlns:inksca\
pe=\x22http://www.i\
nkscape.org/name\
spaces/inkscape\x22\
\x0d\x0a   inkscape:ex\
port-ydpi=\x22900\x22\x0d\
\x0a   inkscape:exp\
ort-xdpi=\x22900\x22\x0d\x0a\
   inkscape:expo\
rt-filename=\x22C:\x5c\
Users\x5cJeffrey\x5cDo\
cuments\x5cpython-d\
ev\x5cephyviewer\x5cgi\
t-repo\x5cephyviewe\
r\x5cephyviewer\x5cico\
ns\x5cimg\x5cepoch-enc\
oder-save.png\x22\x0d\x0a\
   inkscape:vers\
ion=\x221.0 (4035a4\
fb49, 2020-05-01\
)\x22\x0d\x0a   sodipodi:\
docname=\x22epoch-e\
ncoder-save.svg\x22\
\x0d\x0a   id=\x22svg6\x22\x0d\x0a\
   version=\x221.1\x22\
\x0d\x0a   viewBox=\x220 \
0 16 16\x22>\x0d\x0a  <me\
tadata\x0d\x0a     id=\
\x22metadata10\x22>\x0d\x0a \
   <rdf:RDF>\x0d\x0a  \
    <cc:Work\x0d\x0a  \
       rdf:about\
=\x22\x22>\x0d\x0a        <d\
c:format>image/s\
vg+xml</dc:forma\
t>\x0d\x0a        <dc:\
type\x0d\x0a          \
 rdf:resource=\x22h\
ttp://purl.org/d\
c/dcmitype/Still\
Image\x22 />\x0d\x0a     \
   <dc:title></d\
c:title>\x0d\x0a      \
</cc:Work>\x0d\x0a    \
</rdf:RDF>\x0d\x0a  </\
metadata>\x0d\x0a  <so\
dipodi:namedview\
\x0d\x0a     inkscape:\
guide-bbox=\x22true\
\x22\x0d\x0a     showguid\
es=\x22true\x22\x0d\x0a     \
inkscape:bbox-no\
des=\x22true\x22\x0d\x0a    \
 inkscape:snap-b\
box=\x22true\x22\x0d\x0a    \
 inkscape:curren\
t-layer=\x22g1687\x22\x0d\
\x0a     inkscape:w\
indow-maximized=\
\x221\x22\x0d\x0a     inksca\
pe:window-y=\x2241\x22\
\x0d\x0a     inkscape:\
window-x=\x22-9\x22\x0d\x0a \
    inkscape:cy=\
\x229.2193472\x22\x0d\x0a   \
  inkscape:cx=\x221\
.7499975\x22\x0d\x0a     \
inkscape:zoom=\x223\
2\x22\x0d\x0a     showgri\
d=\x22false\x22\x0d\x0a     \
id=\x22namedview8\x22\x0d\
\x0a     inkscape:w\
indow-height=\x2210\
01\x22\x0d\x0a     inksca\
pe:window-width=\
\x221920\x22\x0d\x0a     ink\
scape:pageshadow\
=\x222\x22\x0d\x0a     inksc\
ape:pageopacity=\
\x220\x22\x0d\x0a     guidet\
olerance=\x2210\x22\x0d\x0a \
    gridtoleranc\
e=\x2210\x22\x0d\x0a     obj\
ecttolerance=\x2210\
\x22\x0d\x0a     borderop\
acity=\x221\x22\x0d\x0a     \
bordercolor=\x22#66\
6666\x22\x0d\x0a     page\
color=\x22#ffffff\x22 \
/>\x0d\x0a  <defs\x0d\x0a   \
  id=\x22defs3051\x22>\
\x0d\x0a    <inkscape:\
path-effect\x0d\x0a   \
    background_c\
olor=\x22#ffffffff\x22\
\x0d\x0a       backgro\
und=\x22true\x22\x0d\x0a    \
   hide_mask=\x22fa\
lse\x22\x0d\x0a       inv\
ert=\x22false\x22\x0d\x0a   \
    uri=\x22#mask-p\
owermask-path-ef\
fect1654\x22\x0d\x0a     \
  lpeversion=\x221\x22\
\x0d\x0a       is_visi\
ble=\x22true\x22\x0d\x0a    \
   id=\x22path-effe\
ct1654\x22\x0d\x0a       \
effect=\x22powermas\
k\x22 />\x0d\x0a    <styl\
e\x0d\x0a       id=\x22cu\
rrent-color-sche\
me\x22\x0d\x0a       type\
=\x22text/css\x22>\x0d\x0a  \
    .ColorScheme\
-Text {\x0d\x0a       \
 color:#232629;\x0d\
\x0a      }\x0d\x0a      \
</style>\x0d\x0a  </de\
fs>\x0d\x0a  <g\x0d\x0a     \
transform=\x22matri\
x(0.96019972,0,0\
,0.96019972,0.27\
339817,0.3587027\
)\x22\x0d\x0a     id=\x22g16\
87\x22>\x0d\x0a    <path\x0d\
\x0a       style=\x22f\
ill:#232629;fill\
-rule:evenodd;st\
roke:none;stroke\
-width:1px;strok\
e-linecap:butt;s\
troke-linejoin:m\
iter;stroke-opac\
ity:1\x22\x0d\x0a       d\
=\x22M 0.19496303,0\
.10632601 H 3.22\
2636 l -0.0067,5\
.22857129 8.2425\
4,-4e-7 0.0028,-\
5.22843269 2.156\
25,0.00391 2.281\
25,2.28515629 -4\
.31e-4,13.414201\
5 H 13.987456 V \
9.413359 H 2.055\
0291 v 6.396373 \
H 0.19496303 Z\x22\x0d\
\x0a       id=\x22path\
1662\x22\x0d\x0a       so\
dipodi:nodetypes\
=\x22cccccccccccccc\
\x22 />\x0d\x0a    <rect\x0d\
\x0a       style=\x22c\
olor:#000000;ove\
rflow:visible;fi\
ll:#232629;fill-\
opacity:1;stroke\
:none;stroke-wid\
th:2.057;stroke-\
linecap:square;s\
troke-miterlimit\
:4;stroke-dashar\
ray:none;paint-o\
rder:markers str\
oke fill\x22\x0d\x0a     \
  id=\x22rect1667\x22\x0d\
\x0a       width=\x221\
.96875\x22\x0d\x0a       \
height=\x223.46875\x22\
\x0d\x0a       x=\x228.50\
66624\x22\x0d\x0a       y\
=\x220.95913708\x22 />\
\x0d\x0a    <rect\x0d\x0a   \
    style=\x22color\
:#000000;overflo\
w:visible;fill:#\
232629;fill-opac\
ity:1;stroke:non\
e;stroke-width:2\
.02157;stroke-li\
necap:square;str\
oke-miterlimit:4\
;stroke-dasharra\
y:none;paint-ord\
er:markers strok\
e fill\x22\x0d\x0a       \
id=\x22rect1681\x22\x0d\x0a \
      width=\x2215.\
622641\x22\x0d\x0a       \
height=\x221.104854\
3\x22\x0d\x0a       x=\x220.\
19496302\x22\x0d\x0a     \
  y=\x2214.704878\x22 \
/>\x0d\x0a  </g>\x0d\x0a</sv\
g>\x0d\x0a\
"

qt_resource_name = b"\
\x00\x16\
\x06\x1f\xda\xa7\
\x00e\
\x00p\x00o\x00c\x00h\x00-\x00e\x00n\x00c\x00o\x00d\x00e\x00r\x00-\x00s\x00e\x00e\
\x00k\x00.\x00s\x00v\x00g\
\x00\x16\
\x09\x13\xda\x87\
\x00e\
\x00p\x00o\x00c\x00h\x00-\x00e\x00n\x00c\x00o\x00d\x00e\x00r\x00-\x00u\x00n\x00d\
\x00o\x00.\x00s\x00v\x00g\
\x00\x18\
\x0f\xa4\x8b\xc7\
\x00m\
\x00e\x00d\x00i\x00a\x00-\x00p\x00l\x00a\x00y\x00b\x00a\x00c\x00k\x00-\x00s\x00t\
\x00a\x00r\x00t\x00.\x00s\x00v\x00g\
\x00\x17\
\x09\x10g\xc7\
\x00m\
\x00e\x00d\x00i\x00a\x00-\x00p\x00l\x00a\x00y\x00b\x00a\x00c\x00k\x00-\x00s\x00t\
\x00o\x00p\x00.\x00s\x00v\x00g\
\x00\x16\
\x06\x13\xda\x87\
\x00e\
\x00p\x00o\x00c\x00h\x00-\x00e\x00n\x00c\x00o\x00d\x00e\x00r\x00-\x00r\x00e\x00d\
\x00o\x00.\x00s\x00v\x00g\
\x00\x18\
\x0d*I\xc7\
\x00e\
\x00p\x00o\x00c\x00h\x00-\x00e\x00n\x00c\x00o\x00d\x00e\x00r\x00-\x00d\x00e\x00l\
\x00e\x00t\x00e\x00.\x00s\x00v\x00g\
\x00\x1b\
\x0a\x9e4'\
\x00e\
\x00p\x00o\x00c\x00h\x00-\x00e\x00n\x00c\x00o\x00d\x00e\x00r\x00-\x00d\x00u\x00p\
\x00l\x00i\x00c\x00a\x00t\x00e\x00.\x00s\x00v\x00g\
\x00\x17\
\x09\x1f[\x87\
\x00e\
\x00p\x00o\x00c\x00h\x00-\x00e\x00n\x00c\x00o\x00d\x00e\x00r\x00-\x00s\x00p\x00l\
\x00i\x00t\x00.\x00s\x00v\x00g\
\x00\x16\
\x05i\xda\xa7\
\x00e\
\x00p\x00o\x00c\x00h\x00-\x00e\x00n\x00c\x00o\x00d\x00e\x00r\x00-\x00s\x00a\x00v\
\x00e\x00.\x00s\x00v\x00g\
"

qt_resource_struct = b"\
\x00\x00\x00\x00\x00\x02\x00\x00\x00\x09\x00\x00\x00\x01\
\x00\x00\x00\x00\x00\x00\x00\x00\
\x00\x00\x01\xa6\x00\x00\x00\x00\x00\x01\x00\x00;+\
\x00\x00\x01v\x11\xfb<w\
\x00\x00\x00\xce\x00\x00\x00\x00\x00\x01\x00\x00\x1a\x13\
\x00\x00\x01v\x11\xfb<v\
\x00\x00\x00\x00\x00\x00\x00\x00\x00\x01\x00\x00\x00\x00\
\x00\x00\x01v\x11\xfb<\x83\
\x00\x00\x00\x9a\x00\x00\x00\x00\x00\x01\x00\x00\x18\x9a\
\x00\x00\x01k\xb4\xe2\x10\xc2\
\x00\x00\x002\x00\x00\x00\x00\x00\x01\x00\x00\x09u\
\x00\x00\x01v\x11\xfb<\x86\
\x00\x00\x01r\x00\x01\x00\x00\x00\x01\x00\x006\x92\
\x00\x00\x01v\x11\xfb<\x86\
\x00\x00\x016\x00\x01\x00\x00\x00\x01\x00\x001{\
\x00\x00\x01v\x11\xfb<g\
\x00\x00\x01\x00\x00\x00\x00\x00\x00\x01\x00\x00'\xc2\
\x00\x00\x01v\x11\xfb<b\
\x00\x00\x00d\x00\x00\x00\x00\x00\x01\x00\x00\x17&\
\x00\x00\x01k\xb4\xe2\x10\xc3\
"

def qInitResources():
    QtCore.qRegisterResourceData(0x03, qt_resource_struct, qt_resource_name, qt_resource_data)

def qCleanupResources():
    QtCore.qUnregisterResourceData(0x03, qt_resource_struct, qt_resource_name, qt_resource_data)

qInitResources()
